@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 #
 # Copyright 2008 Zuza Software Foundation
 #
@@ -46,7 +45,6 @@ overwritten and replaced.
 import logging
 import os
 import re
-import six
 from glob import glob
 from shutil import move, rmtree
 from subprocess import PIPE, CalledProcessError, Popen
@@ -64,7 +62,7 @@ class RunProcessError(CalledProcessError):
     def __init__(self, message=None, **kwargs):
         """Use and strip string message='' from kwargs"""
         self._message = message or self._default_message
-        super(RunProcessError, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
     def __str__(self):
         """Format exception message string (avoiding TypeErrors)"""
@@ -92,7 +90,7 @@ def run(cmd, expected_status=0, fail_msg=None, stdout=-1, stderr=-1):
     if stderr == -1:
         stderr = std
 
-    cmdstring = cmd if isinstance(cmd, six.string_types) else ' '.join(cmd)
+    cmdstring = cmd if isinstance(cmd, str) else ' '.join(cmd)
     logger.debug('>>> %s $ %s', os.getcwd(), cmdstring)
     p = Popen(cmd, stdout=stdout, stderr=stderr)
     (output, error) = p.communicate()
