@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 #
 # Copyright 2008 Zuza Software Foundation
 #
@@ -30,10 +29,10 @@
 import glob
 import os
 import shutil
-import six
 import tempfile
 import time
-from subprocess import Popen, PIPE
+from subprocess import PIPE, Popen
+
 
 join = os.path.join
 
@@ -121,7 +120,7 @@ def get_langs(lang_args):
 
     langs = []
 
-    if isinstance(lang_args, six.string_types):
+    if isinstance(lang_args, str):
         if lang_args == 'ALL':
             lang_args = ['ALL']
         elif lang_args == 'ZA':
