@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2013 Zuza Software Foundation
 #
@@ -22,7 +21,6 @@
 .. seealso:: http://en.wikipedia.org/wiki/N'Ko_language
 """
 
-from __future__ import unicode_literals
 
 import re
 
@@ -53,5 +51,5 @@ class nqo(common.Common):
 
     @classmethod
     def punctranslate(cls, text):
-        text = super(cls, cls).punctranslate(text)
+        text = super().punctranslate(text)
         return reverse_quotes(text)
