@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2002-2007 Zuza Software Foundation
 #
@@ -32,14 +31,12 @@ import ctypes.util
 import logging
 import os
 import re
-import six
 import sys
 import tempfile
 from ctypes import (CFUNCTYPE, POINTER, Structure, c_char_p, c_int, c_long,
                     c_size_t, c_uint, cdll)
 
 from translate.lang import data
-from translate.misc.deprecation import deprecated
 from translate.misc.multistring import multistring
 from translate.storage import base, pocommon, pypo
 
@@ -272,11 +269,11 @@ def get_libgettextpo_version():
 
 
 def gpo_encode(value):
-    return value.encode('utf-8') if isinstance(value, six.text_type) else value
+    return value.encode('utf-8') if isinstance(value, str) else value
 
 
 def gpo_decode(value):
-    if isinstance(value, six.text_type):
+    if isinstance(value, str):
         return value
     elif isinstance(value, bytes):
         return value.decode('utf-8')
@@ -353,7 +350,7 @@ class pounit(pocommon.pounit):
                 if remainder:
                     return remainder.group(1)
                 else:
-                    return u""
+                    return ""
             else:
                 return text
         singular = remove_msgid_comments(gpo_decode(gpo.po_message_msgid(self._gpo_message)) or "")
@@ -366,7 +363,7 @@ class pounit(pocommon.pounit):
             else:
                 return singular
         else:
-            return u""
+            return ""
 
     @source.setter
     def source(self, source):
@@ -380,11 +377,6 @@ class pounit(pocommon.pounit):
             gpo.po_message_set_msgid(self._gpo_message, gpo_encode(source))
             gpo.po_message_set_msgid_plural(self._gpo_message, None)
 
-    # Deprecated on 2.3.1
-    @deprecated("Use `source` property instead")
-    def getsource(self):
-        return self.source
-
     @property
     def target(self):
         if self.hasplural():
@@ -398,7 +390,7 @@ class pounit(pocommon.pounit):
             if plurals:
                 multi = multistring(plurals)
             else:
-                multi = multistring(u"")
+                multi = multistring("")
         else:
             multi = gpo_decode(gpo.po_message_msgstr(self._gpo_message)) or ""
         return multi
@@ -409,7 +401,7 @@ class pounit(pocommon.pounit):
         if self.hasplural():
             if isinstance(target, multistring):
                 target = target.strings
-            elif isinstance(target, six.string_types):
+            elif isinstance(target, str):
                 target = [target]
         # for non-plurals: check number of items in 'target'
         elif isinstance(target, (dict, list)):
@@ -435,7 +427,7 @@ class pounit(pocommon.pounit):
                 gpo.po_message_set_msgstr_plural(self._gpo_message, i, gpo_encode(targetstring))
         # add the values of a dict
         elif isinstance(target, dict):
-            for i, targetstring in enumerate(six.itervalues(target)):
+            for i, targetstring in enumerate(target.values()):
                 gpo.po_message_set_msgstr_plural(self._gpo_message, i, gpo_encode(targetstring))
         # add a single string
         else:
@@ -444,11 +436,6 @@ class pounit(pocommon.pounit):
             else:
                 gpo.po_message_set_msgstr(self._gpo_message, gpo_encode(target))
 
-    # Deprecated on 2.3.1
-    @deprecated("Use `target` property instead")
-    def gettarget(self):
-        return self.target
-
     def getid(self):
         """The unique identifier for this unit according to the conventions in
         .mo files.
@@ -463,7 +450,7 @@ class pounit(pocommon.pounit):
 #            id = '%s\0%s' % (id, plural)
         context = gpo.po_message_msgctxt(self._gpo_message)
         if context:
-            id = u"%s\04%s" % (gpo_decode(context), id)
+            id = "%s\04%s" % (gpo_decode(context), id)
         return id
 
     def getnotes(self, origin=None):
@@ -536,7 +523,7 @@ class pounit(pocommon.pounit):
         """
 
         if not isinstance(otherpo, pounit):
-            super(pounit, self).merge(otherpo, overwrite, comments)
+            super().merge(otherpo, overwrite, comments)
             return
         if comments:
             self.addnote(otherpo.getnotes("translator"), origin="translator", position="merge")
@@ -564,7 +551,7 @@ class pounit(pocommon.pounit):
                 self.markfuzzy()
 
     def isheader(self):
-        #return self.source == u"" and self.target != u""
+        #return self.source == "" and self.target != ""
         # we really want to make sure that there is no msgidcomment or msgctxt
         return self.getid() == "" and len(self.target) > 0
 
@@ -613,11 +600,11 @@ class pounit(pocommon.pounit):
             text = gpo_decode(gpo.po_message_msgid(self._gpo_message)) or ""
         if text:
             return pocommon.extract_msgid_comment(text)
-        return u""
+        return ""
 
     def setmsgidcomment(self, msgidcomment):
         if msgidcomment:
-            self.source = u"_: %s\n%s" % (msgidcomment, self.source)
+            self.source = "_: %s\n%s" % (msgidcomment, self.source)
     msgidcomment = property(_extract_msgidcomments, setmsgidcomment)
 
     def __str__(self):
@@ -635,7 +622,7 @@ class pounit(pocommon.pounit):
             if locline == -1:
                 locstring = locname
             else:
-                locstring = u":".join([locname, six.text_type(locline)])
+                locstring = ":".join([locname, str(locline)])
             locations.append(pocommon.unquote_plus(locstring))
             i += 1
             location = gpo.po_message_filepos(self._gpo_message, i)
@@ -719,12 +706,12 @@ class pofile(pocommon.pofile):
             if not noheader:
                 self.init_headers()
         else:
-            super(pofile, self).__init__(inputfile=inputfile, **kwargs)
+            super().__init__(inputfile=inputfile, **kwargs)
 
     def addunit(self, unit, new=True):
         if new:
             gpo.po_message_insert(self._gpo_message_iterator, unit._gpo_message)
-        super(pofile, self).addunit(unit)
+        super().addunit(unit)
 
     def _insert_header(self, header):
         header._store = self
@@ -771,7 +758,7 @@ class pofile(pocommon.pofile):
                     if not thepo_msgctxt == idpo_msgctxt:
                         uniqueunits.append(thepo)
                     else:
-                        logger.warn(
+                        logger.warning(
                             "Duplicate unit found with msgctx of '%s' and source '%s'",
                             thepo_msgctxt,
                             thepo.source)
