@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2008-2009 Zuza Software Foundation
 #
@@ -22,9 +21,8 @@ Contains the ``parse`` function that parses normal strings into StringElem-
 based "rich" string element trees.
 """
 
-import six
 
-from translate.storage.placeables import StringElem
+from translate.storage.placeables.strelem import StringElem
 
 
 def parse(tree, parse_funcs):
@@ -48,7 +46,7 @@ def parse(tree, parse_funcs):
                         form the original string. If nothing could be
                         parsed, it should return ``None``.
     """
-    if isinstance(tree, six.text_type):
+    if isinstance(tree, str):
         tree = StringElem(tree)
     if not parse_funcs:
         return tree
@@ -61,7 +59,7 @@ def parse(tree, parse_funcs):
         if not leaf.istranslatable:
             continue
 
-        unileaf = six.text_type(leaf)
+        unileaf = str(leaf)
         if not unileaf:
             continue
 
@@ -70,7 +68,7 @@ def parse(tree, parse_funcs):
             if (len(subleaves) == 1 and isinstance(subleaves[0], type(leaf)) and
                 leaf == subleaves[0]):
                 pass
-            elif isinstance(leaf, six.text_type):
+            elif isinstance(leaf, str):
                 parent = tree.get_parent_elem(leaf)
                 if parent is not None:
                     if len(parent.sub) == 1:
