@@ -1,11 +1,9 @@
-# -*- coding: utf-8 -*-
-
-from __future__ import print_function, unicode_literals
 
+import pytest
 from lxml import etree
 
-from translate.storage import aresource, test_monolingual
 from translate.misc.multistring import multistring
+from translate.storage import aresource, test_monolingual
 from translate.storage.base import TranslationStore
 
 
@@ -391,6 +389,11 @@ class TestAndroidResourceUnit(test_monolingual.TestMonolingualUnit):
                '</string>\n')
         self.__check_parse(string, xml)
 
+    def test_parse_unicode(self):
+        with pytest.raises(ValueError):
+            self.__check_parse('', r'<string name="test">\utest</string>')
+        self.__check_parse('\u0230', r'<string name="test">\u0230</string>')
+
 
 class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
     StoreClass = aresource.AndroidResourceFile
