@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2008-2009 Zuza Software Foundation
 #
@@ -169,11 +168,11 @@ class TestTSfile(test_base.TestTranslationStore):
         """Test basic plurals"""
         tsfile = ts.tsfile()
         tsunit = tsfile.addsourceunit("File(s)")
-        tsunit.target = [u"Leêr", u"Leêrs"]
+        tsunit.target = ["Leêr", "Leêrs"]
         newfile = ts.tsfile.parsestring(bytes(tsfile))
         print(bytes(tsfile))
         checkunit = newfile.findunit("File(s)")
-        assert checkunit.target == [u"Leêr", u"Leêrs"]
+        assert checkunit.target == ["Leêr", "Leêrs"]
         assert checkunit.hasplural()
 
     def test_nplural(self):
