@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2009, 2013 Zuza Software Foundation
 # Copyright 2013 F Wolff
@@ -23,7 +22,6 @@
 import logging
 import math
 import re
-import six
 import threading
 import time
 from sqlite3 import dbapi2
@@ -44,7 +42,7 @@ class LanguageError(Exception):
         return str(self.value)
 
 
-class TMDB(object):
+class TMDB:
     _tm_dbs = {}
 
     def __init__(self, db_file, max_candidates=3, min_similarity=75,
@@ -54,8 +52,8 @@ class TMDB(object):
         self.min_similarity = min_similarity
         self.max_length = max_length
 
-        if not isinstance(db_file, six.text_type):
-            db_file = six.text_type(db_file)  # don't know which encoding
+        if not isinstance(db_file, str):
+            db_file = str(db_file)  # don't know which encoding
         self.db_file = db_file
         # share connections to same database file between different instances
         if db_file not in self._tm_dbs:
@@ -74,7 +72,7 @@ class TMDB(object):
     def _get_connection(self, index):
         current_thread = threading.currentThread()
         if current_thread not in self._tm_db:
-            connection = dbapi2.connect(self.db_file.encode('utf-8') if six.PY2 else self.db_file)
+            connection = dbapi2.connect(self.db_file)
             cursor = connection.cursor()
             self._tm_db[current_thread] = (connection, cursor)
         return self._tm_db[current_thread][index]
@@ -327,7 +325,7 @@ DROP TRIGGER IF EXISTS sources_delete_trig;
                 })
         results.sort(key=lambda match: match['quality'], reverse=True)
         results = results[:self.max_candidates]
-        logging.debug("results: %s", six.text_type(results))
+        logging.debug("results: %s", str(results))
         return results
 
 
