@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2004-2007 Zuza Software Foundation
 #
@@ -29,7 +28,6 @@ use the newer .ts format which are documented here:
 `2 <http://doc.qt.io/qt-5/qstring.html#arg-2>`_
 """
 
-import six
 
 from translate.misc import ourdom
 
@@ -113,7 +111,7 @@ class QtTsParser:
         if context is None:
             return self.document.searchElementsByTagName("message", self.messageancestors)
         else:
-            if isinstance(context, six.string_types):
+            if isinstance(context, str):
                 # look up the context node by name
                 context = self.getcontextnode(context)
                 if context is None:
